/**
 * Licensed Material - Property of IBM
 * 
 * (C) Copyright IBM Corp. 2003 - All Rights Reserved.
 * US Government Users Restricted Rights - Use, duplication or disclosure
 * restricted by GSA ADP Schedule Contract with IBM Corp.
 *
 * 
 * CLASS: LoggingUtilSample.java
 * 
 * 
 * DESCRIPTION:  Sample class to demonstrate the usage of the com.ibm.etools.logging.util plug-in.
 * 
 * 
 * ASSUMPTIONS:  1) The com.ibm.etools.logging.util plug-in's JAR file (i.e. logutil.jar) located in the 
 *                  'runtime' directory is specified in the CLASSPATH environment variable.
 *               2) The location of a valid JDK 'bin' directory is specified in the PATH environment variable.
 *                
 * COMPILE COMMAND:  javac.exe -classpath logutil.jar LoggingUtilSample.java
 * 
 * EXECUTION COMMAND:  java.exe -classpath logutil.jar LoggingUtilSample
 * 
 * 
 * @author         Paul Slauenwhite
 * @version        1.0 - February 18, 2002
 * @since          JDK 1.3
 * @see   	   MsgLogger
 * @see   	   DefaultMsgLogger
 * @see   	   DefaultRecord
 * @see   	   SubstitutionVariable
 * @see   	   Level
 */

import com.ibm.etools.logging.util.DefaultMsgLogger;
import com.ibm.etools.logging.util.DefaultRecord;
import com.ibm.etools.logging.util.Level;
import com.ibm.etools.logging.util.MsgLogger;
import com.ibm.etools.logging.util.SubstitutionVariable;

import java.awt.Button;
import java.math.BigDecimal;
import java.math.BigInteger;
import java.util.Arrays;
import java.util.Hashtable;
import java.util.Vector;

public class LoggingUtilSample {

    /**
     * Copyright statement.
     */
    public static final String loggingUtilSampleCopyright = "Licensed Material - Property of IBM\n\n(C) Copyright IBM Corp. 2003 - All Rights Reserved.\nUS Government Users Restricted Rights - Use, duplication or disclosure\nrestricted by GSA ADP Schedule Contract with IBM Corp.";

    public LoggingUtilSample() {

        try {
            boolean a1 = true;
            boolean[] a2 = { true, false };

            char b1 = 'c';
            char[] b2 = { '<', '>', '&', '\"', '\'' };

            byte c1 = Byte.MIN_VALUE;
            byte[] c2 = { Byte.MIN_VALUE, Byte.MAX_VALUE };

            short d1 = Short.MIN_VALUE;
            short[] d2 = { Short.MIN_VALUE, Short.MAX_VALUE };

            int e1 = Integer.MIN_VALUE;
            int[] e2 = { Integer.MIN_VALUE, Integer.MAX_VALUE };
            BigInteger e3 = BigInteger.ONE;
            BigDecimal e4 = new BigDecimal(e3);

            long f1 = Long.MIN_VALUE;
            long[] f2 = { Long.MIN_VALUE, Long.MAX_VALUE };

            float g1 = Float.MIN_VALUE;
            float[] g2 = { Float.MIN_VALUE, Float.MAX_VALUE };

            double h1 = Double.MIN_VALUE;
            double[] h2 = { Double.MIN_VALUE, Double.MAX_VALUE };

            Object[] i1 = { a2, b2 };
            Object[][] i2 = { { c2, d2 }, {
                    e2, f2 }
            };
            Object[] i3 = { i1, i2 };
            Object[] i4 = { i1, i2, i3 };

            Object j1 = null;

            String k1 = "String test";
            String[] k2 = { "String-0", "String-1", "<>&\"\'" };
            StringBuffer k3 = new StringBuffer("StringBuffer test");

            Vector l1 = new Vector(Arrays.asList(k2));

            Throwable m1 = new Throwable("Exception test");
            Exception m2 = new Exception();

            Thread n1 = Thread.currentThread();

            Object[] o1 = { k1, k2, l1, m1, n1 };

            Button p1 = new Button();

            SubstitutionVariable[] q1 = { new SubstitutionVariable("booleanKey", a1), new SubstitutionVariable("charKey", b1), new SubstitutionVariable("byteKey", c1), new SubstitutionVariable("shortKey", d1), new SubstitutionVariable("intKey", e1), new SubstitutionVariable("longKey", f1), new SubstitutionVariable("floatKey", g1), new SubstitutionVariable("doubleKey", h1), new SubstitutionVariable("2DObjectArrayKey", i1), new SubstitutionVariable("stringKey", k1), new SubstitutionVariable("stringArrayKey", k2), new SubstitutionVariable("vectorKey", l1), new SubstitutionVariable("throwableKey", m1), new SubstitutionVariable("ThreadKey", n1)};
            DefaultRecord q2 = new DefaultRecord("Product", "Version", "Component Name", this, "Source Method Name", "messageID001", Level.FINER, "Message", q1);
            DefaultRecord q3 = new DefaultRecord();
            DefaultRecord q4 = null;
            DefaultRecord q5 = new DefaultRecord("Product", "Version", "Component Name", "com.ibm.etools.logging.util.LoggingUtilities", "Source Method Name", "messageID001", Level.FINER, "Message", q1);
            DefaultRecord q6 = new DefaultRecord("Product", "Version", "Component Name", new String("TestClassA"), "Source Method Name", "messageID001", Level.FINER, "Message", q1);
            DefaultRecord q7 = null;
            try {
                q7 = new DefaultRecord("Product", "Version", "Component Name", Class.forName("com.ibm.etools.logging.util.LoggingUtilities"), "Source Method Name", "messageID001", Level.FINER, "Message", q1);
            }
            catch (Exception e) {
            }

            Hashtable r1 = new Hashtable();
            r1.put("Hashtable_Key_1", "Hashtable_Value_1");
            r1.put("Hashtable_Key_2", "Hashtable_Value_2");
            r1.put("Hashtable_Key_3", "Hashtable_Value_3");
            r1.put("Hashtable_Key_4", "Hashtable_Value_4");
            r1.put("Hashtable_Key_5", "Hashtable_Value_5");
            r1.put("Hashtable_Key_6", "Hashtable_Value_6");

            Class s1 = r1.getClass();

            MsgLogger logger = (MsgLogger) MsgLogger.getFactory().getLogger("LoggingUtilSample logger");

            logger.setLevel(Level.FINEST);

            logger.setFileName("LoggingUtilSampleLog.xml");

            logger.write(a1);
            logger.write(a2);

            logger.write(b1);
            logger.write(b2);

            logger.write(c1);
            logger.write(c2);

            logger.write(d1);
            logger.write(d2);

            logger.write(e1);
            logger.write(e2);
            logger.write(e3);
            logger.write(e4);

            logger.write(f1);
            logger.write(f2);

            logger.write(g1);
            logger.write(g2);

            logger.write(h1);
            logger.write(h2);

            logger.write(i1);
            logger.write(i2);
            logger.write(i3);
            logger.write(i4);

            logger.write(j1);

            logger.write(k1);
            logger.write(k2);
            logger.write(k3);

            logger.write(l1);

            logger.write(m1);
            logger.write(m2);

            logger.write(n1);

            logger.write(o1);

            logger.write(p1);

            logger.write(q1);
            logger.write(q2);
            logger.write(q3);
            logger.write(q4);
            logger.write(q5);
            logger.write(q6);
            logger.write(q7);

            logger.write(r1);

            logger.write(s1);

            DefaultMsgLogger.setLevel(Level.FINER);

            DefaultMsgLogger.setXMLFormat(false);

            DefaultMsgLogger.setFileName("LoggingUtilSampleLog.txt");

            DefaultMsgLogger.write(Level.FINE, a1);
            DefaultMsgLogger.write(Level.FINE, a2);

            DefaultMsgLogger.write(Level.FINE, b1);
            DefaultMsgLogger.write(Level.FINE, b2);

            DefaultMsgLogger.write(Level.FINE, c1);
            DefaultMsgLogger.write(Level.FINE, c2);

            DefaultMsgLogger.write(Level.FINE, d1);
            DefaultMsgLogger.write(Level.FINE, d2);

            DefaultMsgLogger.write(Level.FINE, e1);
            DefaultMsgLogger.write(Level.FINE, e2);
            DefaultMsgLogger.write(Level.FINE, e3);
            DefaultMsgLogger.write(Level.FINE, e4);

            DefaultMsgLogger.write(Level.FINE, f1);
            DefaultMsgLogger.write(Level.FINE, f2);

            DefaultMsgLogger.write(Level.FINE, g1);
            DefaultMsgLogger.write(Level.FINE, g2);

            DefaultMsgLogger.write(Level.FINE, h1);
            DefaultMsgLogger.write(Level.FINE, h2);

            DefaultMsgLogger.write(Level.FINE, i1);
            DefaultMsgLogger.write(Level.FINE, i2);
            DefaultMsgLogger.write(Level.FINE, i3);
            DefaultMsgLogger.write(Level.FINE, i4);

            DefaultMsgLogger.write(Level.FINE, j1);

            DefaultMsgLogger.write(Level.FINE, k1);
            DefaultMsgLogger.write(Level.FINE, k2);
            DefaultMsgLogger.write(Level.FINE, k3);

            DefaultMsgLogger.write(Level.FINE, l1);

            DefaultMsgLogger.write(Level.FINE, m1);
            DefaultMsgLogger.write(Level.FINE, m2);

            DefaultMsgLogger.write(Level.FINE, n1);

            DefaultMsgLogger.write(Level.FINE, o1);

            DefaultMsgLogger.write(Level.FINE, p1);

            DefaultMsgLogger.write(Level.FINE, q1);
            DefaultMsgLogger.write(Level.FINE, q2);
            DefaultMsgLogger.write(Level.FINE, q3);
            DefaultMsgLogger.write(Level.FINE, q4);
            DefaultMsgLogger.write(Level.FINE, q5);
            DefaultMsgLogger.write(Level.FINE, q6);
            DefaultMsgLogger.write(Level.FINE, q7);

            DefaultMsgLogger.write(Level.FINE, r1);

            DefaultMsgLogger.write(Level.FINE, s1);
            
            System.exit(0);
        }
        catch (Throwable t) {
            t.printStackTrace();
            System.exit(1);            
        }
    }

    public static void main(String[] args) {
        new LoggingUtilSample();
    }
}