/**
 * Licensed Material - Property of IBM
 * 5724-D14
 * (C) Copyright IBM Corp. 2002 - All Rights Reserved.
 * US Government Users Restricted Rights - Use, duplication or disclosure
 * restricted by GSA ADP Schedule Contract with IBM Corp.
 *
 */

import java.util.Random;

import com.ibm.etools.logging.util.Level;
import com.ibm.etools.logging.util.MsgLogger;

/*
 * Created on Jul 2, 2003
 * Demonstrates the rotational logging feature of the MsgLogger API
 */

public class RotationalLoggingSample {

	static Random rnd = new Random();

	/* Constructor */
	public RotationalLoggingSample ()
	{
		/* Create the logger and set the appropriate properties */ 
		MsgLogger logger = (MsgLogger) MsgLogger.getFactory().getLogger("RotationalLoggingSample");
		logger.setLevel(Level.FINEST);
		logger.setFileName("RotationalLogging.txt");
		logger.setXMLFormat(false);
		logger.setMaxSize(1024000);		/* Set maxiumm size at 1MB +- 5KB*/
		
		final int MAX_RECORDS = 25000;  /* Log 25,000 records */
		
		/* Regardless how large MAX_RECORDS is, the log file will never exceed 1MB +- 5KB */	
		for (int i = 0; i < MAX_RECORDS; i++)
			logger.write (getRandomMessage());
	}
	
	
	/* Generates a random message */
	private String getRandomMessage()
	{
		final int POSSIBILITIES = 5;
		int randomMsg = Math.abs(rnd.nextInt() % POSSIBILITIES);
		
		switch (randomMsg)
		{
			case 1:
				return "Message1: Missing library files";
			case 2:
				return "Message2: Make sure the service is properly installed and running";
			case 3:
				return "Message3: Port x is busy, attempt to use a different port";
			case 4:
				return "Message4: Required class [x.class] not found.  Check your classpath and try again";
			default:
				return "Message5: Channels are open for communication";
		}
	}
	
	
	
	/* Launcher
	 * @param args - Used for flags and arguments. */
	public static void main(String[] args) 
	{ new RotationalLoggingSample(); }
}
